==> Theophrastus-1.3.21.10684.tar.gz: Theophrastus-1.3.21.10684/Theophrastus/editor/admin.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 10664 2017-12-19 10:35:03Z David $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2017-12-19 18:35:03 +0800 (Tue, 19 Dec 2017) $
# $Revision: 10664 $

from django import forms
from django.contrib import admin
from django.utils.translation import gettext as _
from django.core.urlresolvers import reverse

from emencia.django.newsletter.models import Newsletter
# #FIXME: Django forms dependencies issues, 
# see https://code.nuwainfo.com/trac/mercurius/ticket/3022
# from emencia.django.newsletter.admin import NewsletterAdmin
from Theophrastus.admin import NewsletterTinyMCEAdmin as NewsletterAdmin

from TinyMCEWidget import CustomTinyMCEWidget

class NewsletterTinyMCEForm(forms.ModelForm):

    content = forms.CharField(
        widget=CustomTinyMCEWidget(attrs={'cols': 150, 'rows': 80}),
        label=_("Content"))

    def clean_header_reply(self):
        """
        Validate reply value.
        """
        reply = self.cleaned_data["header_reply"]
        try:
            reply.encode()
        except UnicodeEncodeError:
            raise forms.ValidationError(
                _("Incorrect value for reply, it can only include English "
                "word, number and symbol."))
        return reply

    class Meta:
        model = Newsletter
        fields = '__all__'

class NewsletterTinyMCEAdmin(NewsletterAdmin):
    
    list_display = ('title', 'getMailingList', 'getServer', 'status',
                    'formatedSendingDate', 'formatedCreationDate',
                    'formatedModificationDate',
                    'historic_link', 'statistics_link')

    def getMailingList(self, obj):
        if obj:
            mailingList = obj.mailing_list
            url = reverse('admin:newsletter_mailinglist_change', args=(mailingList.id,))
            
            return u"<a href='%s'>%s</a>" % (url, mailingList.name)

    def getServer(self, obj):
        if obj:
            server = obj.server
            url = reverse('admin:newsletter_smtpserver_change', args=(server.id,))
    
            return u"<a href='%s'>%s</a>" % (url, server.name)
    
    getMailingList.short_description = _('mailing list')
    getMailingList.allow_tags = True
    getServer.short_description = _('server')
    getServer.allow_tags = True

    def formatedSendingDate(self, obj):
        return obj.sending_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedSendingDate.short_description = _('sending date')

    def formatedCreationDate(self, obj):
        return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedCreationDate.short_description = _('creation date')

    def formatedModificationDate(self, obj):
        return obj.modification_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedModificationDate.short_description = _('modification date')

    class Media:
        try:
            js = [
                'js/Newsletter.js',
            ]
        except AttributeError:
            pass

    form = NewsletterTinyMCEForm

admin.site.unregister(Newsletter)
admin.site.register(Newsletter, NewsletterTinyMCEAdmin)

==> Theophrastus-1.4.2.10858.tar.gz: Theophrastus-1.4.2.10858/Theophrastus/editor/admin.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 10803 2018-03-02 03:45:30Z David $
#
# Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2018-03-02 11:45:30 +0800 (Fri, 02 Mar 2018) $
# $Revision: 10803 $

from django import forms
from django.contrib import admin
from django.utils.translation import gettext as _
from django.core.urlresolvers import reverse

from emencia.django.newsletter.models import Newsletter
# #FIXME: Django forms dependencies issues, 
# see https://code.nuwainfo.com/trac/mercurius/ticket/3022
# from emencia.django.newsletter.admin import NewsletterAdmin
from Theophrastus.newsletter_extension.admin import NewsletterExtensionAdmin \
                                                    as NewsletterAdmin
from Theophrastus.newsletter_extension.admin import NewsletterForm
from TinyMCEWidget import CustomTinyMCEWidget

class NewsletterTinyMCEForm(NewsletterForm):
    def __init__(self, *args, **kwargs):
        super(NewsletterTinyMCEForm, self).__init__(*args, **kwargs)

    content = forms.CharField(
        widget=CustomTinyMCEWidget(attrs={'cols': 150, 'rows': 80}),
        label=_("Content"))

class NewsletterTinyMCEAdmin(NewsletterAdmin):
    form = NewsletterTinyMCEForm

admin.site.unregister(Newsletter)
admin.site.register(Newsletter, NewsletterTinyMCEAdmin)
